import { CountryData } from './data/countries-data';
import { LanguageData } from './data/languages-data';
export declare class Language {
    /**
     * Common name of language (only).
     */
    languageName: string;
    /**
     * Local name of language (only).
     */
    languageLocal: string;
    /**
     * ISO 639-1 language code.
     */
    iso639: string;
    /**
     * Country details if country variety.
     */
    country?: Country | null;
    constructor(languageData: LanguageData, countryCode?: string, countryData?: CountryData | null);
    /**
     * Browser language code.
     */
    readonly code: string;
    /**
     * Common name of language with country.
     */
    readonly name: string;
    /**
     * Local (cultural) name of language with country.
     */
    readonly local: string;
    /**
     * Returns serialized Language object (some libraries aren't handling objects correctly e.g. select2)
     */
    serialized(): any;
}
export interface Country {
    /**
     * Common name of country.
     */
    readonly name: string;
    /**
     * Local name of country.
     */
    readonly local: string;
    /**
     * ISO 3166-1 country code.
     */
    readonly code: string;
}
/**
 * Fetch all available languages.
 */
export declare function all(): Language[];
/**
 * Fetch all available countries.
 */
export declare function allCountries(): Country[];
/**
 * Find desired language via full language code
 * @param languageCode - language code
 */
export declare function find(languageCode: string): Language | null;
export declare function findCountry(countryCode: string): Country | null;
